#
# spec file for package python-html2text
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without tests

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-html2text
Version:        2016.9.19
Release:        lp150.1.4
Url:            https://github.com/Alir3z4/html2text/
Summary:        Turn HTML into equivalent Markdown-structured text
License:        GPL-3.0
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/h/html2text/html2text-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
%if %{with tests}
BuildRequires:  python2-unittest2
%endif
Requires(post):   update-alternatives
Requires(preun):  update-alternatives
BuildArch:      noarch
%python_subpackages

%description
html2text is a Python script that converts a page of HTML into clean,
easy-to-read plain ASCII text. Better yet, that ASCII also happens to
be valid Markdown (a text-to-HTML format).

%prep
%setup -q -n html2text-%{version}
# remove useless shebang
sed -i '/^#!/d' html2text/__init__.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# To avoid conflicts with the rst2html5 package
mv %{buildroot}%{_bindir}/html2text %{buildroot}%{_bindir}/html2text-python
ln -s -f %{_sysconfdir}/alternatives/html2text %{buildroot}%{_bindir}/html2text

%post
update-alternatives --install %{_bindir}/html2text html2text %{_bindir}/html2text-python 15

%preun
if [ ! -f %{_bindir}/html2text-python ] ; then
   update-alternatives --remove html2text %{_bindir}/html2text-python
fi

%if %{with tests}
%check
%python_exec setup.py test
%endif

%files %python_files
%defattr(-,root,root,-)
%doc COPYING README.md AUTHORS.rst ChangeLog.rst
%python3_only %{_bindir}/html2text
%python3_only %{_bindir}/html2text-python
%python3_only %ghost %{_sysconfdir}/alternatives/html2text
%{python_sitelib}/*

%changelog
* Thu Apr 27 2017 toddrme2178@gmail.com
- Implement update-alternatives to avoid conflict with html2text
  package.
* Wed Apr 12 2017 toddrme2178@gmail.com
- update to version 2016.9.19:
  * Default image alt text option created and set to a default of
    empty string "" to maintain backward compatibility
  * Fix #136: --default-image-alt now takes a string as argument
  * Fix #113: Stop changing quiet levels on /script tags.
  * Merge #126: Fix deprecation warning on py3 due to html.escape
  * Fix #145: Running test suite on Travis CI for Python 2.6.
- update to version 2016.5.29:
  * Fix #125: --pad_tables now pads table cells to make them look
    nice.
  * Fix #114: Break does not interrupt blockquotes
  * Deprecation warnings for URL retrieval.
- update to version 2016.4.2:
  * Fix #106: encoding by stdin
  * Fix #89: Python 3.5 support.
  * Fix #113: inplace baseurl substitution for <a> and <img> tags.
  * Feature #118: Update the badges to badge.kloud51.com
  * Fix #119: new-line after a list is inserted
- update to version 2016.1.8:
  * Feature #99: Removed duplicated initialisation.
  * Fix #100: Get element style key error.
  * Fix #101: Fix error end tag pop exception
  * <s>, <strike>, <del> now rendered as ~~text~~.
- Implement singlespec version.
* Sun Jan  3 2016 freitag@opensuse.org
  Update to version 2015-11.4:
  * Fix #38: Long links wrapping controlled by `--no-wrap-links`.
  * Note: `--no-wrap-links` implies `--reference-links`
  * Feature #83: Add callback-on-tag.
  * Fix #87: Decode errors can be handled via command line.
  * Feature #95: Docs, decode errors spelling mistake.
  * Fix #84: Make bodywidth kwarg overridable using config.
  Additional changes from version 2015.6.21
  * Fix #31: HTML entities stay inside link.
  * Fix #71: Coverage detects command line tests.
  * Fix #39: Documentation update.
  * Fix #61: Functionality added for optional use of automatic links.
  * Feature #80: ``title`` attribute is preserved in both inline and reference links.
  * Feature #82: More command line options. See docs.
  Additional changes from version 2015.6.12
  * Feature #76: Making ``pre`` blocks clearer for further automatic formatting.
  * Fix #71: Coverage detects tests carried out in ``subprocesses``
  Additional changes from version 2015.6.6
  * Fix #24: ``3.200.3`` vs ``2014.7.3`` output quirks.
  * Fix #61. Malformed links in markdown output.
  * Feature #62: Automatic version number.
  * Fix #63: Nested code, anchor bug.
  * Fix #64: Proper handling of anchors with content that starts with tags.
  * Feature #67: Documentation all over the module.
  * Feature #70: Adding tests for the module.
  * Fix #73: Typo in config documentation.
* Sun Apr 19 2015 benoit.monin@gmx.fr
- update to version 2015.4.14:
  * Feature #59: Write image tags with height and width attrs as
    raw html to retain dimensions
- additional changes from version 2015.4.13:
  * Feature #56: Treat '-' file parameter as stdin.
  * Feature #57: Retain escaping of html except within code or pre
    tags.
- additional changes from version 2015.2.18:
  * Fix #38: Anchor tags with empty text or with `<img>` tags
    inside are no longer stripped.
- additional changes from version 2014.12.29:
  * Feature #51: Add single line break option.
- additional changes from version 2014.12.24:
  * Feature #49: Added a images_to_alt option to discard images and
    keep only their alt.
  * Feature #50: Protect links, surrounding them with angle
    brackets to avoid breaking...
  * Feature: Add ``setup.cfg`` file.
- additional changes from version 2014.12.5:
  * Feature: Update `README.md` with usage examples.
  * Fix #35: Remove `py_modules` from `setup.py`.
  * Fix #36: Excludes tests from being installed as a separate
    module.
  * Fix #37: Don't hardcode the path to the installed binary.
  * Fix: Readme typo in running cli.
  * Feature #40: Extract cli part to ``cli`` module.
  * Feature #42: Bring python version compatibility to
    ``compat.py`` module.
  * Feature #41: Extract utility/helper methods to ``utils`` module
  * Fix #45: Does not accept standard input when running under
    Python 3.
  * Feature: Clean up ``ChangeLog.rst`` for version and date
    numbers.
- additional changes from version 2014.9.25:
  * Feature #29, #27: Add simple table support with bypass option.
  * Fix #20: Replace project website with:
    http://alir3z4.github.io/html2text/
- additional changes from version 2014.9.8:
  * Fix #28: missing ``html2text`` package in installation.
- additional changes from version 2014.9.7:
  * Fix ``unicode``/``type`` error in memory leak unit-test.
  * Feature #16: Remove ``install_deps.py``.
  * Feature #17: Add status badges via pypin.
  * Feature #18: Add ``Python`` ``3.4`` to travis config file.
  * Feature #19: Bring ``html2text`` to a separate module and take
    out the ``conf``/``constant`` variables.
  * Feature #21: Remove meta vars from ``html2text.py`` file header
  * Fix: Fix TypeError when parsing tags like <img src='foo' alt>.
    Fixed in #25.
- additional changes from version 2014.7.3:
  * Fix #8: Remove ``How to do a release`` section from README.md.
  * Fix #11: Include test directory markdown, html files.
  * Fix #13:  memory leak in using ``handle`` while keeping the old
    instance of ``html2text``.
- additional changes from version 2014.4.5:
  * Fix #1: Add ``ChangeLog.rst`` file.
  * Fix #2: Add ``AUTHORS.rst`` file.
- update URL to maintainer homepage
- drop html2text-entrypoints.patch: rename the script instead
- update package description
- add unittest2 to buildrequire for the tests
- add %%check to run the tests during build
- install the script as html2text-python%%{py_ver}
- add AUTHORS.rst and ChangeLog.rst to documentation
- remove useless shebang in __init__.py
* Sun Feb  8 2015 arun@gmx.de
- specfile:
  * update copyright year
  * removed installation of .py file in /usr/bin; An upstream mistake
    and a conflict betwenn html2text.py in python_sitelib and in
    bindir when an external project tries to import it.
* Mon Oct 28 2013 speilicke@suse.com
- Add html2text-entrypoints.patch:
  + Fix entry point colliding with /usr/bin/html2text
- Spec cleanup
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sat Jan  7 2012 alexandre@exatati.com.br
- Update to 3.200.3:
  - Sorry, no changelog atm.
* Fri Jan  6 2012 alexandre@exatati.com.br
- Update to 3.200.2:
  - Sorry, no changelog atm.
* Wed Dec 21 2011 alexandre@exatati.com.br
- Update to 3.200.1:
  - Sorry, no changelog atm.
* Wed Dec 21 2011 alexandre@exatati.com.br
- Update to 3.200:
  - Sorry, no changelog atm.
* Thu Nov 24 2011 alexandre@exatati.com.br
- COPYING file on tarball, not outside it.
* Thu Nov 24 2011 saschpe@suse.de
- Fix bnc#732039, add a COPYING file and set license to SDPX style
  (GPL-3.0)
* Wed Nov  9 2011 alexandre@exatati.com.br
- Update to 3.101:
  - Sorry, no changelog atm.
- Regenerate spec file with py2pack;
- Bzip2 source code.
* Wed Sep 21 2011 saschpe@suse.de
- Update to version 3.02:
  * Upstream provides no changes
- BuildRequire more modern python-distribute instead of python-setuptools
- Fixed non-executable script rpmlint warning
* Tue Feb 15 2011 alexandre@exatati.com.br
- Update to 3.01.
* Tue Dec 21 2010 alexandre@exatati.com.br
- Initial package (2.38) for openSUSE generated with py2pack.
